@@ -24,7 +24,7 @@ import re
 PROGNAME = 'system-switch-java'
 COPYRIGHT = 'Copyright (C) 2007 Red Hat, Inc.'
 AUTORS = ['Thomas Fitzsimmons <fitzsim@redhat.com>']
-VERSION = '1.1.1'
+VERSION = '1.1.2'
 
 # Internationalization.
 gettext.bindtextdomain(PROGNAME, '/usr/share/locale')
@@ -34,7 +34,6 @@ _ = gettext.gettext
 TEXT_MESSAGE = _('''\
 display text interface even if graphics display is available\
 ''')
-
 PARSE_ERROR_MESSAGE = _('''\
 An attempt to parse /var/lib/alternatives/java failed.\
 ''')
@@ -126,28 +125,42 @@ def get_java_identifiers():
     return java_identifiers, best_identifier
 
 def get_plugin_alternatives(plugin_alternatives, arch):
-    alternatives, best = get_alternatives('libjavaplugin.so' + arch)
-    plugin_expression = re.compile('/usr/lib/jvm/jre-([^/]*)/')
-    for alternative in alternatives:
-        java_search = plugin_expression.search(alternative)
-        if java_search == None:
-            # Skip unrecognized libjavaplugin.so alternative.
-            continue
-        java = java_search.group(1)
-        plugin_alternatives[java] = alternative
+    try:
+        alternatives, best = get_alternatives('libjavaplugin.so' + arch)
+        plugin_expression = re.compile('/usr/lib/jvm/jre-([^/]*)/')
+        for alternative in alternatives:
+            java_search = plugin_expression.search(alternative)
+            if java_search == None:
+                # Skip unrecognized libjavaplugin.so alternative.
+                continue
+            java = java_search.group(1)
+            plugin_alternatives[java] = alternative
+    except JavaParseError:
+        # Ignore libjavaplugin.so parse errors.
+        pass
+    except JavaOpenError:
+        # No libjavaplugin.so alternatives were found.
+        pass
     return plugin_alternatives
 
 def get_javadocdir_alternatives():
     javadocdir_alternatives = {}
-    alternatives, best = get_alternatives('javadocdir')
-    javadocdir_expression = re.compile('/usr/share/javadoc/java-([^/]*)/')
-    for alternative in alternatives:
-        java_search = javadocdir_expression.search(alternative)
-        if java_search == None:
-            # Skip unrecognized javadocdir alternative.
-            continue
-        java = java_search.group(1)
-        javadocdir_alternatives[java] = alternative
+    try:
+        alternatives, best = get_alternatives('javadocdir')
+        javadocdir_expression = re.compile('/usr/share/javadoc/java-([^/]*)/')
+        for alternative in alternatives:
+            java_search = javadocdir_expression.search(alternative)
+            if java_search == None:
+                # Skip unrecognized javadocdir alternative.
+                continue
+            java = java_search.group(1)
+            javadocdir_alternatives[java] = alternative
+    except JavaParseError:
+        # Ignore javadocdir parse errors.
+        pass
+    except JavaOpenError:
+        # No javadocdir alternatives were found.
+        pass
     return javadocdir_alternatives
 
 def get_alternatives(master):
